# Criteo API SDK for Python

## Introduction
API Client Libraries can facilitate your use of the Criteo API allowing you to build unique and customized solutions to serve your businesses and clients.
These libraries can reduce the amount of code you need to write in order to start accessing Criteo programmatically. They also can help expedite troubleshooting, should you encounter any issues.

More information on how to use Criteo API and these SDKs can be found at: [https://developers.criteo.com/](https://developers.criteo.com/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- Package version: 2024.04.0.250626

## Requirements

Python 2.7 and 3.5+

## Installation & Usage
### pip install

```sh
pip install criteo-api-retailmedia-sdk==2024.04.0.250626
```
(you may need to run `pip` with root permission: `sudo pip install criteo-api-retailmedia-sdk==2024.04.0.250626`)

Then import the package:
```python
import criteo_api_retailmedia_v2024_04
```

### Manual Installation using [Setuptools](http://pypi.python.org/pypi/setuptools)

Download the code or clone the repository locally, then execute the following command:

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import criteo_api_retailmedia_v2024_04
```

## Example
There are multiple examples for the different OAuth flows that the SDK supports.
- See [test/example_application_with_client_credentials.py](test/example_application_with_client_credentials.py) for an example with Client Credentials.
- See [test/example_application_with_auth_code.py](test/example_application_with_auth_code.py) for an example with Authorization Code.
Once you follow the authorization code flow, you will have a refresh token that has to be used to regenerate access token for future usage. 
    - See [test/example_application_with_refresh_token.py](test/example_application_with_refresh_token.py) for an example with Refresh Token .

## Documentation for API Endpoints

The developers documentation is available at: *https://developers.criteo.com*.

All URIs are relative to *https://api.criteo.com*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**add_brands**](docs/AccountsApi.md#add_brands) | **POST** /2024-04/retail-media/account-management/accounts/{accountId}/brands/add | 
*AccountsApi* | [**create_private_market_demand_brand_account**](docs/AccountsApi.md#create_private_market_demand_brand_account) | **POST** /2024-04/retail-media/account-management/accounts/{accountId}/create-brand-account | 
*AccountsApi* | [**get_api_v1_external_accounts**](docs/AccountsApi.md#get_api_v1_external_accounts) | **GET** /2024-04/retail-media/accounts | 
*AccountsApi* | [**remove_brands**](docs/AccountsApi.md#remove_brands) | **POST** /2024-04/retail-media/account-management/accounts/{accountId}/brands/remove | 
*AnalyticsApi* | [**generate_async_campaigns_report**](docs/AnalyticsApi.md#generate_async_campaigns_report) | **POST** /2024-04/retail-media/reports/campaigns | 
*AnalyticsApi* | [**generate_async_line_items_report**](docs/AnalyticsApi.md#generate_async_line_items_report) | **POST** /2024-04/retail-media/reports/line-items | 
*AnalyticsApi* | [**generate_async_revenue_report**](docs/AnalyticsApi.md#generate_async_revenue_report) | **POST** /2024-04/retail-media/reports/revenue | 
*AnalyticsApi* | [**get_async_export_output**](docs/AnalyticsApi.md#get_async_export_output) | **GET** /2024-04/retail-media/reports/{reportId}/output | 
*AnalyticsApi* | [**get_async_export_status**](docs/AnalyticsApi.md#get_async_export_status) | **GET** /2024-04/retail-media/reports/{reportId}/status | 
*AudienceApi* | [**legacy_create_audience_v1**](docs/AudienceApi.md#legacy_create_audience_v1) | **POST** /2024-04/retail-media/accounts/{accountId}/audiences | 
*AudienceApi* | [**legacy_get_audience_v1**](docs/AudienceApi.md#legacy_get_audience_v1) | **GET** /2024-04/retail-media/accounts/{accountId}/audiences | 
*AudienceApi* | [**legacy_get_audience_v2**](docs/AudienceApi.md#legacy_get_audience_v2) | **GET** /2024-04/retail-media/v2/accounts/{accountId}/audiences | 
*AudienceApi* | [**legacy_update_audience_v2**](docs/AudienceApi.md#legacy_update_audience_v2) | **POST** /2024-04/retail-media/v2/accounts/{accountId}/audiences | 
*BalanceApi* | [**get_api202110_external_balance_campaigns_by_balance_id**](docs/BalanceApi.md#get_api202110_external_balance_campaigns_by_balance_id) | **GET** /2024-04/retail-media/balances/{balance-id}/campaigns | 
*CampaignApi* | [**add_remove_keywords**](docs/CampaignApi.md#add_remove_keywords) | **POST** /2024-04/retail-media/line-items/{id}/keywords/add-remove | 
*CampaignApi* | [**create_asset**](docs/CampaignApi.md#create_asset) | **POST** /2024-04/retail-media/assets | 
*CampaignApi* | [**fetch_keywords**](docs/CampaignApi.md#fetch_keywords) | **GET** /2024-04/retail-media/line-items/{id}/keywords | 
*CampaignApi* | [**get_api202110_external_account_creatives_by_account_id**](docs/CampaignApi.md#get_api202110_external_account_creatives_by_account_id) | **GET** /2024-04/retail-media/accounts/{account-id}/creatives | 
*CampaignApi* | [**get_api202110_external_auction_line_item_targeting_keywords_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_auction_line_item_targeting_keywords_by_line_item_id) | **GET** /2024-04/retail-media/auction-line-items/{line-item-id}/targeting/keywords | 
*CampaignApi* | [**get_api202110_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#get_api202110_external_campaign_preferred_line_items_by_campaign_id) | **GET** /2024-04/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_by_line_item_id) | **GET** /2024-04/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id) | **GET** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id) | **GET** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences | 
*CampaignApi* | [**get_api202110_external_preferred_line_item_targeting_stores_by_line_item_id**](docs/CampaignApi.md#get_api202110_external_preferred_line_item_targeting_stores_by_line_item_id) | **GET** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores | 
*CampaignApi* | [**get_api202110_external_retailer_pages_by_retailer_id**](docs/CampaignApi.md#get_api202110_external_retailer_pages_by_retailer_id) | **GET** /2024-04/retail-media/retailers/{retailerId}/pages | 
*CampaignApi* | [**get_api202204_external_categorie_by_category_id**](docs/CampaignApi.md#get_api202204_external_categorie_by_category_id) | **GET** /2024-04/retail-media/categories/{categoryId} | 
*CampaignApi* | [**get_api202204_external_categories**](docs/CampaignApi.md#get_api202204_external_categories) | **GET** /2024-04/retail-media/categories | 
*CampaignApi* | [**get_api202207_external_retailer_by_retailer_id_templatestemplate_id**](docs/CampaignApi.md#get_api202207_external_retailer_by_retailer_id_templatestemplate_id) | **GET** /2024-04/retail-media/retailers/{retailer-id}/templates/{template-id} | 
*CampaignApi* | [**get_api202207_external_retailer_templates_by_retailer_id**](docs/CampaignApi.md#get_api202207_external_retailer_templates_by_retailer_id) | **GET** /2024-04/retail-media/retailers/{retailer-id}/templates | 
*CampaignApi* | [**get_api202210_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#get_api202210_external_account_by_account_id_creativescreative_id) | **GET** /2024-04/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**get_api202301_external_account_campaigns_by_account_id**](docs/CampaignApi.md#get_api202301_external_account_campaigns_by_account_id) | **GET** /2024-04/retail-media/accounts/{account-id}/campaigns | 
*CampaignApi* | [**get_api202301_external_campaign_by_campaign_id**](docs/CampaignApi.md#get_api202301_external_campaign_by_campaign_id) | **GET** /2024-04/retail-media/campaigns/{campaignId} | 
*CampaignApi* | [**get_api202301_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#get_api202301_external_line_item_bid_multipliers_by_line_item_id) | **GET** /2024-04/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**get_api_v1_external_account_brands_by_account_id**](docs/CampaignApi.md#get_api_v1_external_account_brands_by_account_id) | **GET** /2024-04/retail-media/accounts/{accountId}/brands | 
*CampaignApi* | [**get_api_v1_external_account_retailers_by_account_id**](docs/CampaignApi.md#get_api_v1_external_account_retailers_by_account_id) | **GET** /2024-04/retail-media/accounts/{accountId}/retailers | 
*CampaignApi* | [**get_api_v1_external_catalog_output_by_catalog_id**](docs/CampaignApi.md#get_api_v1_external_catalog_output_by_catalog_id) | **GET** /2024-04/retail-media/catalogs/{catalogId}/output | 
*CampaignApi* | [**get_api_v1_external_catalog_status_by_catalog_id**](docs/CampaignApi.md#get_api_v1_external_catalog_status_by_catalog_id) | **GET** /2024-04/retail-media/catalogs/{catalogId}/status | 
*CampaignApi* | [**get_api_v2_external_account_line_items_by_account_id**](docs/CampaignApi.md#get_api_v2_external_account_line_items_by_account_id) | **GET** /2024-04/retail-media/accounts/{account-id}/line-items | 
*CampaignApi* | [**get_api_v2_external_auction_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_auction_line_item_by_line_item_id) | **GET** /2024-04/retail-media/auction-line-items/{line-item-id} | 
*CampaignApi* | [**get_api_v2_external_campaign_auction_line_items_by_campaign_id**](docs/CampaignApi.md#get_api_v2_external_campaign_auction_line_items_by_campaign_id) | **GET** /2024-04/retail-media/campaigns/{campaign-id}/auction-line-items | 
*CampaignApi* | [**get_api_v2_external_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_line_item_by_line_item_id) | **GET** /2024-04/retail-media/line-items/{line-item-id} | 
*CampaignApi* | [**get_campaign_budget_overrides**](docs/CampaignApi.md#get_campaign_budget_overrides) | **GET** /2024-04/retail-media/campaigns/{campaignId}/campaign-budget-overrides | 
*CampaignApi* | [**get_line_item_budget_overrides**](docs/CampaignApi.md#get_line_item_budget_overrides) | **GET** /2024-04/retail-media/line-items/{lineItemId}/line-item-budget-overrides | 
*CampaignApi* | [**post_api202110_external_auction_line_item_targeting_keywords_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_auction_line_item_targeting_keywords_append_by_line_item_id) | **POST** /2024-04/retail-media/auction-line-items/{line-item-id}/targeting/keywords/append | 
*CampaignApi* | [**post_api202110_external_auction_line_item_targeting_keywords_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_auction_line_item_targeting_keywords_delete_by_line_item_id) | **POST** /2024-04/retail-media/auction-line-items/{line-item-id}/targeting/keywords/delete | 
*CampaignApi* | [**post_api202110_external_balance_campaigns_append_by_balance_id**](docs/CampaignApi.md#post_api202110_external_balance_campaigns_append_by_balance_id) | **POST** /2024-04/retail-media/balances/{balance-id}/campaigns/append | 
*CampaignApi* | [**post_api202110_external_balance_campaigns_delete_by_balance_id**](docs/CampaignApi.md#post_api202110_external_balance_campaigns_delete_by_balance_id) | **POST** /2024-04/retail-media/balances/{balance-id}/campaigns/delete | 
*CampaignApi* | [**post_api202110_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#post_api202110_external_campaign_preferred_line_items_by_campaign_id) | **POST** /2024-04/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_add_to_basket_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_add_to_basket_append_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_add_to_basket_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_add_to_basket_delete_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket/delete | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_audiences_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_audiences_append_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_audiences_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_audiences_delete_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences/delete | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_stores_append_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_stores_append_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores/append | 
*CampaignApi* | [**post_api202110_external_preferred_line_item_targeting_stores_delete_by_line_item_id**](docs/CampaignApi.md#post_api202110_external_preferred_line_item_targeting_stores_delete_by_line_item_id) | **POST** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores/delete | 
*CampaignApi* | [**post_api202210_external_account_creatives_by_account_id**](docs/CampaignApi.md#post_api202210_external_account_creatives_by_account_id) | **POST** /2024-04/retail-media/accounts/{account-id}/creatives | 
*CampaignApi* | [**post_api202210_external_account_creatives_search_by_account_id**](docs/CampaignApi.md#post_api202210_external_account_creatives_search_by_account_id) | **POST** /2024-04/retail-media/accounts/{account-id}/creatives/search | 
*CampaignApi* | [**post_api202301_external_account_campaigns_by_account_id**](docs/CampaignApi.md#post_api202301_external_account_campaigns_by_account_id) | **POST** /2024-04/retail-media/accounts/{account-id}/campaigns | 
*CampaignApi* | [**post_api_v1_external_account_catalogs_by_account_id**](docs/CampaignApi.md#post_api_v1_external_account_catalogs_by_account_id) | **POST** /2024-04/retail-media/accounts/{accountId}/catalogs | 
*CampaignApi* | [**post_api_v2_external_campaign_auction_line_items_by_campaign_id**](docs/CampaignApi.md#post_api_v2_external_campaign_auction_line_items_by_campaign_id) | **POST** /2024-04/retail-media/campaigns/{campaign-id}/auction-line-items | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_by_line_item_id) | **PUT** /2024-04/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_add_to_basket_by_line_item_id) | **PUT** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/add-to-basket | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_audiences_by_line_item_id) | **PUT** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/audiences | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_targeting_stores_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_targeting_stores_by_line_item_id) | **PUT** /2024-04/retail-media/preferred-line-items/{line-item-id}/targeting/stores | 
*CampaignApi* | [**put_api202210_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#put_api202210_external_account_by_account_id_creativescreative_id) | **PUT** /2024-04/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**put_api202301_external_campaign_by_campaign_id**](docs/CampaignApi.md#put_api202301_external_campaign_by_campaign_id) | **PUT** /2024-04/retail-media/campaigns/{campaignId} | 
*CampaignApi* | [**put_api202301_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#put_api202301_external_line_item_bid_multipliers_by_line_item_id) | **PUT** /2024-04/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**put_api_v2_external_auction_line_item_by_line_item_id**](docs/CampaignApi.md#put_api_v2_external_auction_line_item_by_line_item_id) | **PUT** /2024-04/retail-media/auction-line-items/{line-item-id} | 
*CampaignApi* | [**set_keyword_bids**](docs/CampaignApi.md#set_keyword_bids) | **POST** /2024-04/retail-media/line-items/{id}/keywords/set-bid | 
*CampaignApi* | [**update_campaign_budget_overrides**](docs/CampaignApi.md#update_campaign_budget_overrides) | **PUT** /2024-04/retail-media/campaigns/{campaignId}/campaign-budget-overrides | 
*CampaignApi* | [**update_line_item_budget_overrides**](docs/CampaignApi.md#update_line_item_budget_overrides) | **PUT** /2024-04/retail-media/line-items/{lineItemId}/line-item-budget-overrides | 
*GatewayApi* | [**get_current_application**](docs/GatewayApi.md#get_current_application) | **GET** /2024-04/retail-media/me | 


## Documentation For Models

 - [AddRemoveKeywordModel](docs/AddRemoveKeywordModel.md)
 - [AddRemoveKeywordsModel](docs/AddRemoveKeywordsModel.md)
 - [AddRemoveKeywordsModelRequest](docs/AddRemoveKeywordsModelRequest.md)
 - [AddRemoveKeywordsModelResource](docs/AddRemoveKeywordsModelResource.md)
 - [AddToBasketIdsUpdateModel202110Request](docs/AddToBasketIdsUpdateModel202110Request.md)
 - [AddToBasketTarget202110Request](docs/AddToBasketTarget202110Request.md)
 - [AddToBasketTarget202110Response](docs/AddToBasketTarget202110Response.md)
 - [ApplicationSummaryModel](docs/ApplicationSummaryModel.md)
 - [ApplicationSummaryModelResource](docs/ApplicationSummaryModelResource.md)
 - [ApplicationSummaryModelResponse](docs/ApplicationSummaryModelResponse.md)
 - [Asset](docs/Asset.md)
 - [AssetResource](docs/AssetResource.md)
 - [AssetResponse](docs/AssetResponse.md)
 - [AsyncCampaignsReport](docs/AsyncCampaignsReport.md)
 - [AsyncCampaignsReportRequest](docs/AsyncCampaignsReportRequest.md)
 - [AsyncCampaignsReportResource](docs/AsyncCampaignsReportResource.md)
 - [AsyncLineItemsReport](docs/AsyncLineItemsReport.md)
 - [AsyncLineItemsReportRequest](docs/AsyncLineItemsReportRequest.md)
 - [AsyncLineItemsReportResource](docs/AsyncLineItemsReportResource.md)
 - [AsyncReportResponse](docs/AsyncReportResponse.md)
 - [AsyncRevenueReport](docs/AsyncRevenueReport.md)
 - [AsyncRevenueReportRequest](docs/AsyncRevenueReportRequest.md)
 - [AsyncRevenueReportResource](docs/AsyncRevenueReportResource.md)
 - [AuctionLineItemCreateModelRequest](docs/AuctionLineItemCreateModelRequest.md)
 - [AuctionLineItemPagedListResponse](docs/AuctionLineItemPagedListResponse.md)
 - [AuctionLineItemResponse](docs/AuctionLineItemResponse.md)
 - [AuctionLineItemUpdateModelRequest](docs/AuctionLineItemUpdateModelRequest.md)
 - [AudienceIdsUpdateModel202110Request](docs/AudienceIdsUpdateModel202110Request.md)
 - [AudienceTarget202110Request](docs/AudienceTarget202110Request.md)
 - [AudienceTarget202110Response](docs/AudienceTarget202110Response.md)
 - [BalanceCampaign202110ListRequest](docs/BalanceCampaign202110ListRequest.md)
 - [BalanceCampaign202110PagedListResponse](docs/BalanceCampaign202110PagedListResponse.md)
 - [CampaignAttributesV202301](docs/CampaignAttributesV202301.md)
 - [CampaignBudgetOverrides](docs/CampaignBudgetOverrides.md)
 - [CampaignDailyBudgetOverride](docs/CampaignDailyBudgetOverride.md)
 - [CampaignMonthlyBudgetOverride](docs/CampaignMonthlyBudgetOverride.md)
 - [CampaignV202301](docs/CampaignV202301.md)
 - [Category202204](docs/Category202204.md)
 - [Category202204ListResponse](docs/Category202204ListResponse.md)
 - [ChoiceOption](docs/ChoiceOption.md)
 - [ChoiceVariableSpecification](docs/ChoiceVariableSpecification.md)
 - [ChoiceVariableValue](docs/ChoiceVariableValue.md)
 - [ColorVariableValue](docs/ColorVariableValue.md)
 - [CommonError](docs/CommonError.md)
 - [CommonLineItemPagedListResponse](docs/CommonLineItemPagedListResponse.md)
 - [CommonLineItemResponse](docs/CommonLineItemResponse.md)
 - [CommonProblem](docs/CommonProblem.md)
 - [CommonWarning](docs/CommonWarning.md)
 - [Creative202110](docs/Creative202110.md)
 - [Creative202110ListResponse](docs/Creative202110ListResponse.md)
 - [Creative202210](docs/Creative202210.md)
 - [Creative202210ListResponse](docs/Creative202210ListResponse.md)
 - [Creative202210Response](docs/Creative202210Response.md)
 - [CreativeCreateModel202207](docs/CreativeCreateModel202207.md)
 - [CreativeUpdateModel202207](docs/CreativeUpdateModel202207.md)
 - [DailyLineItemBudgetOverride](docs/DailyLineItemBudgetOverride.md)
 - [EditableCampaignAttributesV202301](docs/EditableCampaignAttributesV202301.md)
 - [EntityResourceOfRetailMediaAccount](docs/EntityResourceOfRetailMediaAccount.md)
 - [EntityResourceOutcomeOfRetailMediaAccount](docs/EntityResourceOutcomeOfRetailMediaAccount.md)
 - [ExternalAccount](docs/ExternalAccount.md)
 - [ExternalAddToBasketIdsUpdateModel202110](docs/ExternalAddToBasketIdsUpdateModel202110.md)
 - [ExternalAddToBasketTarget202110](docs/ExternalAddToBasketTarget202110.md)
 - [ExternalAuctionLineItem](docs/ExternalAuctionLineItem.md)
 - [ExternalAuctionLineItemCreateModel](docs/ExternalAuctionLineItemCreateModel.md)
 - [ExternalAuctionLineItemUpdateModel](docs/ExternalAuctionLineItemUpdateModel.md)
 - [ExternalAudienceIdsUpdateModel202110](docs/ExternalAudienceIdsUpdateModel202110.md)
 - [ExternalAudienceTarget202110](docs/ExternalAudienceTarget202110.md)
 - [ExternalBrand](docs/ExternalBrand.md)
 - [ExternalCatalogRequest](docs/ExternalCatalogRequest.md)
 - [ExternalCatalogStatus](docs/ExternalCatalogStatus.md)
 - [ExternalCommonLineItem](docs/ExternalCommonLineItem.md)
 - [ExternalKeywordTarget202110](docs/ExternalKeywordTarget202110.md)
 - [ExternalLineItemCapping202110](docs/ExternalLineItemCapping202110.md)
 - [ExternalLineItemPage202110](docs/ExternalLineItemPage202110.md)
 - [ExternalLineItemPageCategory202110](docs/ExternalLineItemPageCategory202110.md)
 - [ExternalPreferredLineItem202110](docs/ExternalPreferredLineItem202110.md)
 - [ExternalPreferredLineItemCreateModel202110](docs/ExternalPreferredLineItemCreateModel202110.md)
 - [ExternalPreferredLineItemUpdateModel202110](docs/ExternalPreferredLineItemUpdateModel202110.md)
 - [ExternalRetailMediaAccount](docs/ExternalRetailMediaAccount.md)
 - [ExternalRetailMediaBrandAccountCreation](docs/ExternalRetailMediaBrandAccountCreation.md)
 - [ExternalRetailMediaBrands](docs/ExternalRetailMediaBrands.md)
 - [ExternalRetailer](docs/ExternalRetailer.md)
 - [ExternalRetailerPages202110](docs/ExternalRetailerPages202110.md)
 - [ExternalStoreIdsUpdateModel202110](docs/ExternalStoreIdsUpdateModel202110.md)
 - [ExternalStoreTarget202110](docs/ExternalStoreTarget202110.md)
 - [FilesVariableValue](docs/FilesVariableValue.md)
 - [FilesVariablesSpecification](docs/FilesVariablesSpecification.md)
 - [HyperlinkVariableValue](docs/HyperlinkVariableValue.md)
 - [InputKeywordsModel](docs/InputKeywordsModel.md)
 - [InputResourceOfAuctionLineItemCreateModel](docs/InputResourceOfAuctionLineItemCreateModel.md)
 - [InputResourceOfPreferredLineItemCreateModel202110](docs/InputResourceOfPreferredLineItemCreateModel202110.md)
 - [JsonApiBodyWithExternalIdOfEditableCampaignAttributesV202301AndCampaignV202301](docs/JsonApiBodyWithExternalIdOfEditableCampaignAttributesV202301AndCampaignV202301.md)
 - [JsonApiBodyWithIdOfInt64AndAccountAndAccount](docs/JsonApiBodyWithIdOfInt64AndAccountAndAccount.md)
 - [JsonApiBodyWithIdOfInt64AndBrandAndBrand](docs/JsonApiBodyWithIdOfInt64AndBrandAndBrand.md)
 - [JsonApiBodyWithIdOfInt64AndCampaignV202301AndCampaignV202301](docs/JsonApiBodyWithIdOfInt64AndCampaignV202301AndCampaignV202301.md)
 - [JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus](docs/JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus.md)
 - [JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersAndLineItemBidMultipliers](docs/JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersAndLineItemBidMultipliers.md)
 - [JsonApiBodyWithIdOfInt64AndRetailerAndRetailer](docs/JsonApiBodyWithIdOfInt64AndRetailerAndRetailer.md)
 - [JsonApiBodyWithoutIdOfCampaignAttributesV202301AndCampaignV202301](docs/JsonApiBodyWithoutIdOfCampaignAttributesV202301AndCampaignV202301.md)
 - [JsonApiBodyWithoutIdOfCatalogRequestAndCatalogRequest](docs/JsonApiBodyWithoutIdOfCatalogRequestAndCatalogRequest.md)
 - [JsonApiPageResponseOfAccount](docs/JsonApiPageResponseOfAccount.md)
 - [JsonApiPageResponseOfBrand](docs/JsonApiPageResponseOfBrand.md)
 - [JsonApiPageResponseOfCampaignV202301](docs/JsonApiPageResponseOfCampaignV202301.md)
 - [JsonApiPageResponseOfRetailer](docs/JsonApiPageResponseOfRetailer.md)
 - [JsonApiRequestOfCatalogRequest](docs/JsonApiRequestOfCatalogRequest.md)
 - [JsonApiSingleResponseOfCampaignV202301](docs/JsonApiSingleResponseOfCampaignV202301.md)
 - [JsonApiSingleResponseOfCatalogStatus](docs/JsonApiSingleResponseOfCatalogStatus.md)
 - [JsonApiSingleResponseOfLineItemBidMultipliers](docs/JsonApiSingleResponseOfLineItemBidMultipliers.md)
 - [KeywordDataModel](docs/KeywordDataModel.md)
 - [KeywordTarget202110Request](docs/KeywordTarget202110Request.md)
 - [KeywordTarget202110Response](docs/KeywordTarget202110Response.md)
 - [KeywordsModel](docs/KeywordsModel.md)
 - [KeywordsModelResource](docs/KeywordsModelResource.md)
 - [KeywordsModelResponse](docs/KeywordsModelResponse.md)
 - [LineItemBidMultipliers](docs/LineItemBidMultipliers.md)
 - [LineItemBidMultipliersRequest](docs/LineItemBidMultipliersRequest.md)
 - [LineItemBidMultipliersResponse](docs/LineItemBidMultipliersResponse.md)
 - [LineItemBudgetOverrides](docs/LineItemBudgetOverrides.md)
 - [MatchTypeModel](docs/MatchTypeModel.md)
 - [MonthlyLineItemBudegetOverride](docs/MonthlyLineItemBudegetOverride.md)
 - [PageMetadata](docs/PageMetadata.md)
 - [PageTypeEnvironment202210](docs/PageTypeEnvironment202210.md)
 - [PostCampaignV202301](docs/PostCampaignV202301.md)
 - [PreferredLineItem202110PagedListResponse](docs/PreferredLineItem202110PagedListResponse.md)
 - [PreferredLineItem202110Response](docs/PreferredLineItem202110Response.md)
 - [PreferredLineItemCreateModel202110Request](docs/PreferredLineItemCreateModel202110Request.md)
 - [PreferredLineItemUpdateModel202110Request](docs/PreferredLineItemUpdateModel202110Request.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [PutCampaignV202301](docs/PutCampaignV202301.md)
 - [ReportOutcome](docs/ReportOutcome.md)
 - [ResourceOfAuctionLineItem](docs/ResourceOfAuctionLineItem.md)
 - [ResourceOfAuctionLineItemUpdateModel](docs/ResourceOfAuctionLineItemUpdateModel.md)
 - [ResourceOfBalanceCampaign202110](docs/ResourceOfBalanceCampaign202110.md)
 - [ResourceOfCategory202204](docs/ResourceOfCategory202204.md)
 - [ResourceOfCommonLineItem](docs/ResourceOfCommonLineItem.md)
 - [ResourceOfCreative202110](docs/ResourceOfCreative202110.md)
 - [ResourceOfCreative202210](docs/ResourceOfCreative202210.md)
 - [ResourceOfLineItemBidMultipliers](docs/ResourceOfLineItemBidMultipliers.md)
 - [ResourceOfPreferredLineItem202110](docs/ResourceOfPreferredLineItem202110.md)
 - [ResourceOfPreferredLineItemUpdateModel202110](docs/ResourceOfPreferredLineItemUpdateModel202110.md)
 - [ResourceOfTemplate](docs/ResourceOfTemplate.md)
 - [ResourceOutcome](docs/ResourceOutcome.md)
 - [ReviewStateModel](docs/ReviewStateModel.md)
 - [RmLegacyAudienceCreateEntityV1](docs/RmLegacyAudienceCreateEntityV1.md)
 - [RmLegacyAudienceCreateEntityV1Resource](docs/RmLegacyAudienceCreateEntityV1Resource.md)
 - [RmLegacyAudienceCreateEntityV1Response](docs/RmLegacyAudienceCreateEntityV1Response.md)
 - [RmLegacyAudienceCreateEntityV2](docs/RmLegacyAudienceCreateEntityV2.md)
 - [RmLegacyAudienceCreateEntityV2Resource](docs/RmLegacyAudienceCreateEntityV2Resource.md)
 - [RmLegacyAudienceCreateEntityV2Response](docs/RmLegacyAudienceCreateEntityV2Response.md)
 - [RmLegacyAudienceCreateInputEntityV1](docs/RmLegacyAudienceCreateInputEntityV1.md)
 - [RmLegacyAudienceCreateInputEntityV2](docs/RmLegacyAudienceCreateInputEntityV2.md)
 - [RmLegacyAudienceGetEntityV1](docs/RmLegacyAudienceGetEntityV1.md)
 - [RmLegacyAudienceGetEntityV1ListResponse](docs/RmLegacyAudienceGetEntityV1ListResponse.md)
 - [RmLegacyAudienceGetEntityV1Resource](docs/RmLegacyAudienceGetEntityV1Resource.md)
 - [RmLegacyAudienceGetEntityV2](docs/RmLegacyAudienceGetEntityV2.md)
 - [RmLegacyAudienceGetEntityV2ListResponse](docs/RmLegacyAudienceGetEntityV2ListResponse.md)
 - [RmLegacyAudienceGetEntityV2Resource](docs/RmLegacyAudienceGetEntityV2Resource.md)
 - [RmLegacyAudienceUserBehaviorCreateV2](docs/RmLegacyAudienceUserBehaviorCreateV2.md)
 - [RmLegacyAudienceUserBehaviorDetailsV2](docs/RmLegacyAudienceUserBehaviorDetailsV2.md)
 - [RmLegacySegmentCustomerList](docs/RmLegacySegmentCustomerList.md)
 - [RmLegacySegmentUserBehaviorCreateV2](docs/RmLegacySegmentUserBehaviorCreateV2.md)
 - [RmLegacySegmentUserBehaviorV1](docs/RmLegacySegmentUserBehaviorV1.md)
 - [RmLegacySegmentUserBehaviorV2](docs/RmLegacySegmentUserBehaviorV2.md)
 - [RmcaCommonProblem](docs/RmcaCommonProblem.md)
 - [SdkApiRestCommonProblem](docs/SdkApiRestCommonProblem.md)
 - [Section](docs/Section.md)
 - [SetBidModel](docs/SetBidModel.md)
 - [SetBidsModel](docs/SetBidsModel.md)
 - [SetBidsModelRequest](docs/SetBidsModelRequest.md)
 - [SetBidsModelResource](docs/SetBidsModelResource.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [StatusResponseResource](docs/StatusResponseResource.md)
 - [StoreIdsUpdateModel202110Request](docs/StoreIdsUpdateModel202110Request.md)
 - [StoreTarget202110Request](docs/StoreTarget202110Request.md)
 - [StoreTarget202110Response](docs/StoreTarget202110Response.md)
 - [Template](docs/Template.md)
 - [TemplateListResponse](docs/TemplateListResponse.md)
 - [TemplateResponse](docs/TemplateResponse.md)
 - [TemplateVariable](docs/TemplateVariable.md)
 - [TemplateVariableValue](docs/TemplateVariableValue.md)
 - [TextVariableSpecification](docs/TextVariableSpecification.md)
 - [TextVariableValue](docs/TextVariableValue.md)
 - [ValueResourceInputOfCampaignBudgetOverrides](docs/ValueResourceInputOfCampaignBudgetOverrides.md)
 - [ValueResourceInputOfLineItemBudgetOverrides](docs/ValueResourceInputOfLineItemBudgetOverrides.md)
 - [ValueResourceInputOfRetailMediaBrandAccountCreation](docs/ValueResourceInputOfRetailMediaBrandAccountCreation.md)
 - [ValueResourceInputOfRetailMediaBrands](docs/ValueResourceInputOfRetailMediaBrands.md)
 - [ValueResourceOfCampaignBudgetOverrides](docs/ValueResourceOfCampaignBudgetOverrides.md)
 - [ValueResourceOfLineItemBudgetOverrides](docs/ValueResourceOfLineItemBudgetOverrides.md)
 - [ValueResourceOfRetailMediaBrandAccountCreation](docs/ValueResourceOfRetailMediaBrandAccountCreation.md)
 - [ValueResourceOfRetailMediaBrands](docs/ValueResourceOfRetailMediaBrands.md)
 - [ValueResourceOutcomeOfCampaignBudgetOverrides](docs/ValueResourceOutcomeOfCampaignBudgetOverrides.md)
 - [ValueResourceOutcomeOfLineItemBudgetOverrides](docs/ValueResourceOutcomeOfLineItemBudgetOverrides.md)
 - [ValueResourceOutcomeOfRetailMediaBrands](docs/ValueResourceOutcomeOfRetailMediaBrands.md)
 - [ValueTypeResourceOfAddToBasketIdsUpdateModel202110](docs/ValueTypeResourceOfAddToBasketIdsUpdateModel202110.md)
 - [ValueTypeResourceOfAddToBasketTarget202110](docs/ValueTypeResourceOfAddToBasketTarget202110.md)
 - [ValueTypeResourceOfAudienceIdsUpdateModel202110](docs/ValueTypeResourceOfAudienceIdsUpdateModel202110.md)
 - [ValueTypeResourceOfAudienceTarget202110](docs/ValueTypeResourceOfAudienceTarget202110.md)
 - [ValueTypeResourceOfKeywordTarget202110](docs/ValueTypeResourceOfKeywordTarget202110.md)
 - [ValueTypeResourceOfStoreIdsUpdateModel202110](docs/ValueTypeResourceOfStoreIdsUpdateModel202110.md)
 - [ValueTypeResourceOfStoreTarget202110](docs/ValueTypeResourceOfStoreTarget202110.md)
 - [VideoVariableValue](docs/VideoVariableValue.md)


## Disclaimer

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.